@@ -288,6 +288,8 @@ class GraphQLClient:
             method_name += 'timeline_minutes'
         elif from_id.startswith('News') and to_id.startswith('Timeline'):
             method_name += 'timeline_news'
+        elif from_id.startswith('Bill') and to_id.startswith('Committee'):
+            method_name += 'bill_belonged_to_committees'
         else:
             raise GraphQLException(f'unknown id types to link: from={from_id} to={to_id}')
 
